@@ -46,10 +46,10 @@
 #include "gbc_output.h"
 
 
-/*#define DEBUG*/
-/*#define DEBUG_MORE*/
+//#define DEBUG
+//#define DEBUG_MORE
 
-static CLASS *Class;
+static CLASS *_class;
 
 static int StringAddr;
 static TABLE *StringTable;
@@ -361,28 +361,30 @@ static void output_header(void)
 static void output_class(void)
 {
 	short flag;
-	begin_section("Class", 1);
+	begin_section("_class", 1);
 
 	// Parent class
-	write_short(Class->parent);
+	write_short(_class->parent);
 	
 	// Class flags
 	flag = 0;
-	if (Class->exported) flag |= 1;
-	if (Class->autocreate) flag |= 2;
-	if (Class->optional) flag |= 4;
-	if (Class->nocreate) flag |= 8;
-	if (Class->has_fast) flag |= 16;
+	if (_class->exported) flag |= 1;
+	if (_class->autocreate) flag |= 2;
+	if (_class->optional) flag |= 4;
+	if (_class->nocreate) flag |= 8;
+	if (_class->has_fast) flag |= 16;
+	if (JOB->is_test) flag |= 32;
+
 	write_short(flag);
 	
 	// Static size
-	write_int(Class->size_stat);
+	write_int(_class->size_stat);
 	
 	// Dynamic size
-	write_int(Class->size_dyn);
+	write_int(_class->size_dyn);
 	
 	// Number of structures
-	write_short(ARRAY_count(Class->structure));
+	write_short(ARRAY_count(_class->structure));
 	
 	// reserved
 	write_short(0);
@@ -398,14 +400,14 @@ static void output_desc(void)
 	TYPE type;
 	short out_type;
 
-	n = TABLE_count(Class->table);
+	n = TABLE_count(_class->table);
 
 	begin_section("Description", 6 * sizeof(int));
 
 	for (i = 0; i < n; i++)
 	{
-		csym = (CLASS_SYMBOL *)TABLE_get_symbol_sort(Class->table, i);
-		//csym = (CLASS_SYMBOL *)TABLE_get_symbol(Class->table, csym->symbol.sort);
+		csym = (CLASS_SYMBOL *)TABLE_get_symbol_sort(_class->table, i);
+		//csym = (CLASS_SYMBOL *)TABLE_get_symbol(_class->table, csym->symbol.sort);
 
 		type = csym->global.type;
 
@@ -438,9 +440,9 @@ static void output_desc(void)
 				case TK_PROPERTY:
 
 					/* read */
-					write_int(Class->prop[csym->global.value].read);
+					write_int(_class->prop[csym->global.value].read);
 					/* write */
-					write_int(Class->prop[csym->global.value].write);
+					write_int(_class->prop[csym->global.value].write);
 					/* flag */
 					write_int(0);
 
@@ -529,13 +531,13 @@ static void output_constant(void)
 	SYMBOL *sym;
 	//TABLE *table;
 
-	n = ARRAY_count(Class->constant);
+	n = ARRAY_count(_class->constant);
 
 	begin_section("Constants", 3 * sizeof(int));
 
 	for (i = 0; i < n; i++)
 	{
-		constant = &Class->constant[i];
+		constant = &_class->constant[i];
 
 		/* type */
 		write_type(constant->type);
@@ -555,7 +557,7 @@ static void output_constant(void)
 
 			case T_SINGLE: case T_FLOAT:
 
-				sym = TABLE_get_symbol(Class->table, constant->value);
+				sym = TABLE_get_symbol(_class->table, constant->value);
 				write_int(get_string(sym->name, sym->len));
 				write_int(sym->len);
 				break;
@@ -569,7 +571,7 @@ static void output_constant(void)
 				}
 				else
 				{
-					sym = TABLE_get_symbol(Class->string, constant->value);
+					sym = TABLE_get_symbol(_class->string, constant->value);
 					write_int(get_string(sym->name, sym->len));
 					write_int(sym->len);
 				}
@@ -587,14 +589,14 @@ static void output_class_ref(void)
 	SYMBOL *sym;
 	CLASS_REF *ref;
 
-	n = ARRAY_count(Class->class);
+	n = ARRAY_count(_class->class);
 
 	begin_section("External classes", sizeof(int));
 
 	for (i = 0; i < n; i++)
 	{
-		ref = &Class->class[i];
-		sym = TABLE_get_symbol(Class->table, ref->index);
+		ref = &_class->class[i];
+		sym = TABLE_get_symbol(_class->table, ref->index);
 		if (ref->used)
 		{
 			if (ref->exported)
@@ -604,7 +606,7 @@ static void output_class_ref(void)
 		}
 		else
 		{
-			if (JOB->verbose)
+			if (COMP_verbose)
 				printf("Ignoring class %.*s\n", sym->len, sym->name);
 			write_int(-1);
 		}
@@ -619,13 +621,13 @@ static void output_unknown_ref(void)
 	int i, n;
 	SYMBOL *sym;
 
-	n = ARRAY_count(Class->unknown);
+	n = ARRAY_count(_class->unknown);
 
 	begin_section("External symbols", sizeof(int));
 
 	for (i = 0; i < n; i++)
 	{
-		sym = TABLE_get_symbol(Class->table, Class->unknown[i]);
+		sym = TABLE_get_symbol(_class->table, _class->unknown[i]);
 		write_int(get_string(sym->name, sym->len));
 	}
 
@@ -638,18 +640,18 @@ static void output_static(void)
 	int i, n;
 	VARIABLE *var;
 
-	n = ARRAY_count(Class->stat);
+	n = ARRAY_count(_class->stat);
 
 	begin_section("Static variables", 2 * sizeof(int));
 
 	for (i = 0; i < n; i++)
 	{
-		var = &Class->stat[i];
+		var = &_class->stat[i];
 
 		/* type */
 		write_type(var->type);
 		/* addr */
-		write_int(var->pos);
+		write_int(0);
 	}
 
 	end_section();
@@ -661,18 +663,18 @@ static void output_dynamic(void)
 	int i, n;
 	VARIABLE *var;
 
-	n = ARRAY_count(Class->dyn);
+	n = ARRAY_count(_class->dyn);
 
 	begin_section("Dynamic variables", 2 * sizeof(int));
 
 	for (i = 0; i < n; i++)
 	{
-		var = &Class->dyn[i];
+		var = &_class->dyn[i];
 
 		/* type */
 		write_type(var->type);
 		/* addr */
-		write_int(var->pos);
+		write_int(0);
 	}
 
 	end_section();
@@ -685,13 +687,13 @@ static void output_event(void)
 	EVENT *event;
 	SYMBOL *sym;
 
-	n = ARRAY_count(Class->event);
+	n = ARRAY_count(_class->event);
 
 	begin_section("Events", 4 * sizeof(int));
 
 	for (i = 0; i < n; i++)
 	{
-		event = &Class->event[i];
+		event = &_class->event[i];
 
 		/* type */
 		write_type(event->type);
@@ -702,7 +704,7 @@ static void output_event(void)
 		/* desc_param */
 		write_int(0);
 		/* name */
-		sym = TABLE_get_symbol(Class->table, event->name);
+		sym = TABLE_get_symbol(_class->table, event->name);
 		write_int(get_string(sym->name, sym->len));
 	}
 
@@ -716,13 +718,13 @@ static void output_extern(void)
 	EXTFUNC *ext;
 	SYMBOL *sym;
 
-	n = ARRAY_count(Class->ext_func);
+	n = ARRAY_count(_class->ext_func);
 
 	begin_section("Extern functions", 5 * sizeof(int));
 
 	for (i = 0; i < n; i++)
 	{
-		ext = &Class->ext_func[i];
+		ext = &_class->ext_func[i];
 
 		/* type */
 		write_type(ext->type);
@@ -735,16 +737,16 @@ static void output_extern(void)
 		/* desc_param */
 		write_int(0);
 		/* name */
-		/*sym = TABLE_get_symbol(Class->table, ext->name);
+		/*sym = TABLE_get_symbol(_class->table, ext->name);
 		write_int(get_string(sym->name, sym->len));*/
 		/* alias name */
 		if (ext->alias == NO_SYMBOL)
-			sym = TABLE_get_symbol(Class->table, ext->name);
+			sym = TABLE_get_symbol(_class->table, ext->name);
 		else
-			sym = TABLE_get_symbol(Class->string, ext->alias);
+			sym = TABLE_get_symbol(_class->string, ext->alias);
 		write_int(get_string(sym->name, sym->len));
 		/* library name */
-		sym = TABLE_get_symbol(Class->string, ext->library);
+		sym = TABLE_get_symbol(_class->string, ext->library);
 		write_int(get_string(sym->name, sym->len));
 	}
 
@@ -759,13 +761,13 @@ static void output_method(void)
 	uchar flag;
 	/*SYMBOL *sym;*/
 
-	n = ARRAY_count(Class->function);
+	n = ARRAY_count(_class->function);
 
 	begin_section("Methods", 8 * sizeof(int));
 
 	for (i = 0; i < n; i++)
 	{
-		func = &Class->function[i];
+		func = &_class->function[i];
 
 		write_type(func->type);
 		write_byte(func->nparam);
@@ -817,9 +819,9 @@ static void output_param_local(void)
 
 	begin_section("Parameters", sizeof(int));
 
-	for (i = 0; i < ARRAY_count(Class->function); i++)
+	for (i = 0; i < ARRAY_count(_class->function); i++)
 	{
-		func = &Class->function[i];
+		func = &_class->function[i];
 
 		for (j = 0; j < func->nparam; j++)
 		{
@@ -833,9 +835,9 @@ static void output_param_local(void)
 		}
 	}
 
-	for (i = 0; i < ARRAY_count(Class->event); i++)
+	for (i = 0; i < ARRAY_count(_class->event); i++)
 	{
-		event = &Class->event[i];
+		event = &_class->event[i];
 
 		for (j = 0; j < event->nparam; j++)
 		{
@@ -846,9 +848,9 @@ static void output_param_local(void)
 		}
 	}
 
-	for (i = 0; i < ARRAY_count(Class->ext_func); i++)
+	for (i = 0; i < ARRAY_count(_class->ext_func); i++)
 	{
-		ext = &Class->ext_func[i];
+		ext = &_class->ext_func[i];
 
 		for (j = 0; j < ext->nparam; j++)
 		{
@@ -870,18 +872,18 @@ static void output_array(void)
 
 	begin_section("Arrays", sizeof(int));
 
-	p = ARRAY_count(Class->array) * sizeof(int);
+	p = ARRAY_count(_class->array) * sizeof(int);
 
-	for (i = 0; i < ARRAY_count(Class->array); i++)
+	for (i = 0; i < ARRAY_count(_class->array); i++)
 	{
-		array = &Class->array[i];
+		array = &_class->array[i];
 		write_int(p);
 		p += sizeof(int) + array->ndim * sizeof(int);
 	}
 
-	for (i = 0; i < ARRAY_count(Class->array); i++)
+	for (i = 0; i < ARRAY_count(_class->array); i++)
 	{
-		array = &Class->array[i];
+		array = &_class->array[i];
 
 		write_type(array->type);
 
@@ -906,14 +908,14 @@ static void output_structure(void)
 	VARIABLE *field;
 	SYMBOL *sym;
 
-	for (i = 0; i < ARRAY_count(Class->structure); i++)
+	for (i = 0; i < ARRAY_count(_class->structure); i++)
 	{
-		structure = &Class->structure[i];
+		structure = &_class->structure[i];
 		
 		begin_section("Structure", sizeof(int));
 		
 		// Structure name
-		sym = TABLE_get_symbol(Class->table, structure->index);
+		sym = TABLE_get_symbol(_class->table, structure->index);
 		write_int(get_string(sym->name, sym->len));
 		
 		for (j = 0; j < structure->nfield; j++)
@@ -921,7 +923,7 @@ static void output_structure(void)
 			field = &structure->field[j];
 			
 			// Field name
-			sym = TABLE_get_symbol(Class->table, field->index);
+			sym = TABLE_get_symbol(_class->table, field->index);
 			write_int(get_string(sym->name, sym->len));
 			
 			// Field datatype
@@ -938,9 +940,9 @@ static void output_code()
 	int n;
 	FUNCTION *func;
 
-	for (i = 0; i < ARRAY_count(Class->function); i++)
+	for (i = 0; i < ARRAY_count(_class->function); i++)
 	{
-		func = &Class->function[i];
+		func = &_class->function[i];
 
 		n = func->ncode;
 
@@ -965,10 +967,10 @@ static void output_debug_global()
 
 	begin_section("Global symbol table", 4 * sizeof(int));
 
-	for (i = 0; i < TABLE_count(Class->table); i++)
+	for (i = 0; i < TABLE_count(_class->table); i++)
 	{
-		csym = (CLASS_SYMBOL *)TABLE_get_symbol_sort(Class->table, i);
-		//csym = (CLASS_SYMBOL *)TABLE_get_symbol(Class->table, csym->symbol.sort);
+		csym = (CLASS_SYMBOL *)TABLE_get_symbol_sort(_class->table, i);
+		//csym = (CLASS_SYMBOL *)TABLE_get_symbol(_class->table, csym->symbol.sort);
 
 		type = csym->global.type;
 		switch (TYPE_get_kind(type))
@@ -1021,9 +1023,9 @@ static void output_debug_method()
 
 	begin_section("Debug method info", 5 * sizeof(int));
 
-	for (i = 0; i < ARRAY_count(Class->function); i++)
+	for (i = 0; i < ARRAY_count(_class->function); i++)
 	{
-		func = &Class->function[i];
+		func = &_class->function[i];
 
 		if (func->pos_line != NULL && func->line < FORM_FIRST_LINE && func->name != NO_SYMBOL)
 		{
@@ -1033,7 +1035,7 @@ static void output_debug_method()
 			/* pos_line */
 			write_int(0);
 			/* nom */
-			name = get_symbol_name(Class->table, func->name, &len);
+			name = get_symbol_name(_class->table, func->name, &len);
 			write_int(get_string(name, len));
 			/* local symbols */
 			write_int(0);
@@ -1057,9 +1059,9 @@ static void output_debug_method()
 
 	end_section();
 
-	for (i = 0; i < ARRAY_count(Class->function); i++)
+	for (i = 0; i < ARRAY_count(_class->function); i++)
 	{
-		func = &Class->function[i];
+		func = &_class->function[i];
 
 		begin_section("Debug method lines", sizeof(short));
 		
@@ -1079,9 +1081,9 @@ static void output_debug_method()
 		end_section();
 	}
 
-	for (i = 0; i < ARRAY_count(Class->function); i++)
+	for (i = 0; i < ARRAY_count(_class->function); i++)
 	{
-		func = &Class->function[i];
+		func = &_class->function[i];
 
 		begin_section("Debug method local symbols", sizeof(int) * 3);
 
@@ -1093,7 +1095,7 @@ static void output_debug_method()
 			{
 				param = &func->local[j];
 				
-				name = get_symbol_name(Class->table, param->index, &len);
+				name = get_symbol_name(_class->table, param->index, &len);
 				index = TABLE_add_symbol(table, name, len);
 				osym = (OUTPUT_SYMBOL *)TABLE_get_symbol(table, index);
 				osym->value = param->value;/*TYPE_long(param->type);*/
@@ -1255,15 +1257,15 @@ static void output_translation(void)
 		"\"Content-Type: text/plain; charset=UTF-8\\n\"\n"
 		"\"Content-Transfer-Encoding: 8bit\\n\"\n\n");
 
-	n = ARRAY_count(Class->constant);
+	n = ARRAY_count(_class->constant);
 
 	for (i = 0; i < n; i++)
 	{
-		constant = &Class->constant[i];
+		constant = &_class->constant[i];
 		if (TYPE_get_id(constant->type) != T_CSTRING)
 			continue;
 
-		sym = TABLE_get_symbol(Class->string, constant->value);
+		sym = TABLE_get_symbol(_class->string, constant->value);
 		if (sym->len == 0)
 			continue;
 
@@ -1348,7 +1350,7 @@ void OUTPUT_do(bool swap)
 	if (!_file)
 		THROW("Cannot create file: &1", name);
 
-	Class = JOB->class;
+	_class = JOB->class;
 
 	#ifdef DEBUG
 	printf("pos = %lu\n", get_pos());
